## base-django-project
This is a base project for django work.
It contains a handful of django apps that I find useful installed by default.
Specifically:
- dj_database_url for extracting a database configuration from a valid DB URI
- django-extensions for running a more powerful shell
- django-fsm for easily creating state machines to track complex processes through the application
- django-simple-history for easily creating history tables for our models in order to improve application auditability
- djangorestframework for easily creating REST APIs


### Usage
In your project's `settings.py`, remove all default configuration generated by django.
Then at the top, simply put:
```
from base_django_project.webapp.settings import *

# place any custom modifications here
```

### Motivation
When standing up many django projects over a short amount of time, I often find myself duplicating configurations. This project allows any user to quickly drop in their favorite default configuration for `settings.py`.
